@@ -1,4 +1,9 @@
 package Test::Class::Moose::Load;
+{
+  $Test::Class::Moose::Load::VERSION = '0.07';
+}
+
+# ABSTRACT: Load L<Test::Class::Moose> classes automatically.
 
 use strict;
 use warnings;
@@ -6,8 +11,6 @@ use warnings;
 use File::Find;
 use File::Spec;
 
-our $VERSION = '0.06';
-
 # Override to get your own filter
 sub is_test_class {
     my ( $class, $file, $dir ) = @_;
@@ -62,30 +65,28 @@ sub import {
 
 __END__
 
+=pod
+
 =head1 NAME
 
-Test::Class::Moose::Load - Load C<Test::Class::Moose> classes automatically.
+Test::Class::Moose::Load - Load L<Test::Class::Moose> classes automatically.
 
 =head1 VERSION
 
-Version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
  use Test::Class::Moose::Load qw(t/tests t/lib);
  Test::Class::Moose->runtests;
 
-=head1 EXPORT
-
-None.
-
 =head1 DESCRIPTION
 
-Note: This helper module was blatantly stolen from C<Test::Class::Load>.
+Note: This helper module was blatantly stolen from L<Test::Class::Load>.
 However, since your author is the person who originally wrote that code, he
 doesn't feel too bad.
 
-C<Test::Class::Moose> typically uses a helper script to load the test classes.
+L<Test::Class::Moose> typically uses a helper script to load the test classes.
 It often looks something like this:
 
  #!/usr/bin/perl -T
@@ -107,12 +108,16 @@ see that all tests pass, even though you don't notice that it didn't run your
 new test class.  Or you delete a test class and you forget to remove it from
 the helper script.
 
-C<Test::Class::Moose::Load> automatically finds and loads your test classes
+L<Test::Class::Moose::Load> automatically finds and loads your test classes
 for you. There is no longer a need to list them individually.
 
+=head1 EXPORT
+
+None.
+
 =head1 BASIC USAGE
 
-Using C<Test::Class::Moose::Load> is as simple as this:
+Using L<Test::Class::Moose::Load> is as simple as this:
 
  #!/usr/bin/perl -T
 
@@ -122,7 +127,7 @@ Using C<Test::Class::Moose::Load> is as simple as this:
  use Test::Class::Moose::Load 't/tests';
 
  Test::Class::Moose->new(\%args)->runtests;
- 
+
 That will search through all files in the C<t/tests> directory and
 automatically load anything which ends in C<.pm>. You should only put test
 classes in those directories.
@@ -139,22 +144,22 @@ of them in the import list.
 
 =head1 ADVANCED USAGE
 
-Here's some examples of advanced usage of C<Test::Class::Moose::Load>.
+Here's some examples of advanced usage of L<Test::Class::Moose::Load>.
 
 =head2 FILTER LOADED CLASSES
 
 You can redefine the filtering criteria, that is, decide what classes are
 picked up and what others are not. You do this simply by subclassing
-C<Test::Class::Moose::Load> overriding the C<is_test_class()> method. You
+L<Test::Class::Moose::Load> overriding the C<is_test_class()> method. You
 might want to do this to only load modules which inherit from
-C<Test::Class::Moose>, or anything else for that matter. 
+L<Test::Class::Moose>, or anything else for that matter. 
 
 =over 4
 
 =item B<is_test_class>
 
   $is_test_class = $class->is_test_class( $file, $directory )
-  
+
 Returns true if C<$file> in C<$directory> should be considered a test class
 and be loaded by L<Test::Class::Moose::Load>. The default filter simply
 returns true if C<$file> ends with C<.pm>
@@ -189,7 +194,7 @@ One problem with this style of testing is that you run I<all> of the tests
 every time you need to test something.  If you want to run only one test
 class, it's problematic.  The easy way to do this is to change your helper
 script by deleting the C<runtests> call:
- 
+
  #!/usr/bin/perl -T
 
  use strict;
@@ -218,12 +223,12 @@ to run:
  prove -lv -It/tests Some::Test::Class::Moose
 
 You can even automate this by binding it to a key in C<vim>:
-    
+
  noremap ,t  :!prove -lv -It/tests %<CR>
 
 Then you can just type C<,t> ('comma', 'tee') and it will run the tests for
 your test class or the tests for your test script (if you're using a
-traditional C<Test::More> style script).
+traditional L<Test::More> style script).
 
 Of course, you can still run your helper script with C<prove>, C<make test> or
 C<./Build test> to run all of your test classes.
@@ -233,17 +238,13 @@ test class directories.
 
 =head1 SECURITY
 
-C<Test::Class::Moose::Load> is taint safe.  Because we're reading the class
+L<Test::Class::Moose::Load> is taint safe.  Because we're reading the class
 names from the directory structure, they're marked as tainted when running
 under taint mode.  We use the following ultra-paranoid bit of code to untaint
 them. Please file a bug report if this is too restrictive.
 
  my ($package) = $_package =~ /^([[:word:]]+(?:::[[:word:]]+)*)$/;
 
-=head1 AUTHOR
-
-Curtis "Ovid" Poe, C<< <ovid@cpan.org> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -255,11 +256,17 @@ I make changes.
 =head1 ACKNOWLEDGMENTS
 
 Thanks to David Wheeler for the idea and Adrian Howard for
-C<Test::Class::Moose>.
+L<Test::Class::Moose>.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006 Curtis "Ovid" Poe, all rights reserved.
+Curtis "Ovid" Poe <ovid@cpan.org>
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Curtis "Ovid" Poe.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
